@@ -93,7 +93,6 @@ you can filter the function with a simple python expression
  * ``titi`` match ``rouge and not carre``
 """
 
-from __future__ import print_function
 
 import os
 import re
@@ -102,7 +101,7 @@ import os.path as osp
 from time import process_time, time
 
 try:
-    from re import Match
+    from re import Match  # type: ignore
 except ImportError:
     # Match is python > 3.6 only.
     #
